@@ -16,21 +16,27 @@ class CmdGet(CmdBase):
         super().__init__(args)
     def run(self):
         start = timer()
-        # prompt_to_get()
         repo = get_repo()
         version = self.args.version
-        commit_id = get_repo_commit_id(json.dumps({"repo_name":repo, "version":version}))
-        # if not get_dvc_data_status():
-        user_input = input("Are you sure you want to get it? [y/n]").lower()
-        if user_input == 'y':
+        if not version:
             print("Files downloading...") 
-            run_command_on_subprocess('git reset --hard {}'.format(commit_id)) 
+            run_command_on_subprocess('git pull') 
             run_command_on_subprocess('dvc pull -f') 
             print("Files downloaded successfully") 
             logger.debug('DOWNLOAD TIME {0}'.format(timedelta(seconds=timer()-start))) 
         else:
-            print("Please enter valid input")
-                 
+            commit_id = get_repo_commit_id(json.dumps({"repo_name":repo, "version":version}))
+            
+            user_input = input("Are you sure you want to get it? [y/n]").lower()
+            if user_input == 'y':
+                print("Files downloading...") 
+                run_command_on_subprocess('git reset --hard {}'.format(commit_id)) 
+                run_command_on_subprocess('dvc pull -f') 
+                print("Files downloaded successfully") 
+                logger.debug('DOWNLOAD TIME {0}'.format(timedelta(seconds=timer()-start))) 
+            else:
+                print("Please enter valid input")
+
         return 0
 
 
@@ -51,7 +57,7 @@ def add_parser(subparsers, parent_parser):
         "-v", 
         "--version", 
         nargs="?", 
-        required=True,
+        default=None,
         type=int,
         help="Repo commit version",
     )
